/*******************************************************************************
 * Copyright (c) 2022  Xilinx, Inc. All rights reserved.
 * All rights reserved. This software is made available under
 * the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * Xilinx, Inc.
 * Copyright 2022  Xilinx, Inc. All Rights Reserved.
 *******************************************************************************/

package org.eclipse.tcf.dap;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.concurrent.ExecutionException;

import org.eclipse.lsp4j.debug.services.IDebugProtocolClient;
import org.eclipse.lsp4j.jsonrpc.Launcher;
import org.eclipse.lsp4j.jsonrpc.debug.DebugLauncher;
import org.eclipse.tcf.internal.dap.TCFDebugAdapter;

public class App {
	private static final String CONNECTION = "[TCF Debug Adapter] HOST=%s PORT=%d";

	public static void main(String[] args) {
		try {
			ServerSocket socket = new ServerSocket(0);
			// provide connection information to parse in our debug adapter plugin
			System.err.println(String.format(CONNECTION, socket.getInetAddress().getHostName(), socket.getLocalPort()));

			final Socket clientSocket = socket.accept();

			TCFDebugAdapter debugAdapter = new TCFDebugAdapter();
			final Launcher<IDebugProtocolClient> launcher = DebugLauncher.createLauncher(debugAdapter,
					IDebugProtocolClient.class, clientSocket.getInputStream(), clientSocket.getOutputStream());

			debugAdapter.connect(launcher.getRemoteProxy());
			debugAdapter.setRemoteEndpoint(launcher.getRemoteEndpoint());

			launcher.startListening().get();

			if (!socket.isClosed()) {
				socket.close();
			}
		} catch (IOException | InterruptedException | ExecutionException exception) {
			exception.printStackTrace();
		}
	}
}
