/*******************************************************************************
 * Copyright (c) 2022  Xilinx, Inc. All rights reserved.
 * All rights reserved. This software is made available under
 * the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * Xilinx, Inc.
 * Copyright 2022  Xilinx, Inc. All Rights Reserved.
 *******************************************************************************/

package org.eclipse.tcf.internal.dap;

import java.io.IOException;
import java.nio.file.*;
import java.nio.file.attribute.BasicFileAttributes;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.logging.Level;
import java.util.logging.Logger;

import static java.nio.file.FileVisitResult.CONTINUE;
import static java.nio.file.FileVisitResult.SKIP_SUBTREE;

public class TCFLocalFileVisitor extends SimpleFileVisitor<Path> {
    private final List<Path> filePaths = new ArrayList<>();
    protected static final Logger LOGGER = Logger.getLogger(TCFLocalFileVisitor.class.getSimpleName());
    public FileVisitResult preVisitDirectory(Path dir, BasicFileAttributes attrs) throws IOException {
        if (dir.getFileName().toString().startsWith(".")) {
            return SKIP_SUBTREE;
        }
        return CONTINUE;
    }
    public FileVisitResult visitFile(Path file,
                                     BasicFileAttributes attr) {
        if (attr.isRegularFile()) {
            System.out.format("Regular file: %s ", file);
            filePaths.add(file);
        } else {
            LOGGER.log(Level.WARNING,"Not a regular file" + file);
        }

        return CONTINUE;
    }
    @Override
    public FileVisitResult visitFileFailed(Path file, IOException exc) {
        if (exc instanceof FileSystemLoopException) {
            LOGGER.log(Level.SEVERE,"cycle detected: " + file);
            LOGGER.log(Level.SEVERE, exc.toString());
        } else {
            LOGGER.log(Level.SEVERE, String.format("Unable to access:" + " %s: %s%n", file, exc));
            LOGGER.log(Level.SEVERE, exc.toString());
        }
        return CONTINUE;
    }

    public List<Path> getFilePaths(){
        return filePaths;
    }

//    public static void main(String[] args) throws IOException {
//        String platformDir = "/tmp/platrepo";
//        EnumSet<FileVisitOption> opts = EnumSet.of(FOLLOW_LINKS);
//        XpfmFileVisitor visitor = new XpfmFileVisitor();
//        Files.walkFileTree(Paths.get(platformDir), opts, 4, visitor);
//        System.out.println("------------------\nXpfm files Discovered\n------------------\n");
//        for(Path xpfm : visitor.getXpfmPaths()){
////            PlatformLoader loader = new PlatformLoader(xpfm.toAbsolutePath().toString(), PlatformLoader.HwMetadataMode.AUTO);
////            SDXPlatform sdxPlatform = loader.load();
////
////              System.out.println( " For " + xpfm.toAbsolutePath().toString());
////            System.out.println( sdxPlatform.getName());
//        }
//        System.out.println("\n------------------END------------------");
//
//    }
}